@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,7 +27,7 @@ SieveInfoWidget::SieveInfoWidget(QWidget *parent)
     : QWidget(parent)
 {
     QHBoxLayout *lay = new QHBoxLayout(this);
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     mInfo = new QTextEdit(this);
     mInfo->setReadOnly(true);
     mInfo->setAcceptRichText(true);
